import matplotlib.pyplot as plt

import os

def use_style(style_name="mn_adi"):
    """Apply a custom Matplotlib style."""
    style_path = os.path.join(os.path.dirname(__file__), "styles", f"{style_name}.mplstyle")
    plt.style.use(style_path)

# As a default, apply the mn_thesis style
use_style(style_name="mn_adi")


from setuptools import setup, find_packages

setup(
    name='mn_mpl_style',
    version='0.3',
    packages=find_packages(),
    include_package_data=True,
    install_requires=['matplotlib'],
    description='A collection of custom Matplotlib styles.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Matt Nagle',
    author_email='mattnagle96@gmail.com',
    url='https://github.com/matt-nagle/mn_mpl_style',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
